You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tapestry.apache.org by hl...@apache.org on 2008/03/01 00:03:57 UTC

svn commit: r632485 - in /tapestry/tapestry5/trunk/tapestry-core/src: main/java/org/apache/tapestry/corelib/components/ main/java/org/apache/tapestry/internal/services/ main/resources/org/apache/tapestry/ site/apt/ site/apt/guide/

Author: hlship
Date: Fri Feb 29 15:03:56 2008
New Revision: 632485

URL: http://svn.apache.org/viewvc?rev=632485&view=rev
Log:
Rename Tapestry.ZoneEffect to Tapestry.ElementEffect

Modified:
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/FormFragment.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/FormInjector.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/Zone.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/internal/services/ClientBehaviorSupport.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry/tapestry.js
    tapestry/tapestry5/trunk/tapestry-core/src/site/apt/guide/ajax.apt
    tapestry/tapestry5/trunk/tapestry-core/src/site/apt/upgrade.apt

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/FormFragment.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/FormFragment.java?rev=632485&r1=632484&r2=632485&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/FormFragment.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/FormFragment.java Fri Feb 29 15:03:56 2008
@@ -56,7 +56,7 @@
 
 
     /**
-     * Name of a function on the client-side Tapestry.ZoneEffect object that is invoked to
+     * Name of a function on the client-side Tapestry.ElementEffect object that is invoked to
      * make the fragment  visible.  If not specified, then
      * the default "slidedown" function is used.
      */
@@ -64,7 +64,7 @@
     private String _show;
 
     /**
-     * Name of a function on the client-side Tapestry.ZoneEffect object that is invoked
+     * Name of a function on the client-side Tapestry.ElementEffect object that is invoked
      * when the fragment is to be hidden. If not specified, the default "slideup" function is used.
      */
     @Parameter(defaultPrefix = TapestryConstants.LITERAL_BINDING_PREFIX)

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/FormInjector.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/FormInjector.java?rev=632485&r1=632484&r2=632485&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/FormInjector.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/FormInjector.java Fri Feb 29 15:03:56 2008
@@ -57,7 +57,7 @@
     private InsertPosition _position;
 
     /**
-     * Name of a function on the client-side Tapestry.ZoneEffect object that is invoked to make added content visible.
+     * Name of a function on the client-side Tapestry.ElementEffect object that is invoked to make added content visible.
      * Leaving as null uses the default function, "highlight".
      */
     @Parameter(defaultPrefix = TapestryConstants.LITERAL_BINDING_PREFIX)

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/Zone.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/Zone.java?rev=632485&r1=632484&r2=632485&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/Zone.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/corelib/components/Zone.java Fri Feb 29 15:03:56 2008
@@ -35,7 +35,7 @@
  * When a user clicks an {@link org.apache.tapestry.corelib.components.ActionLink} whose zone parameter is set,
  * the corresponding client-side Tapestry.Zone object is located. It will update the content of the Zone's <div> and
  * then invoke either a show method (if the div is not visible) or an update method (if the div is visible).  The show and update
- * parameters are the <em>names</em> of functions attached to the Tapestry.ZoneEffect object.
+ * parameters are the <em>names</em> of functions attached to the Tapestry.ElementEffect object.
  * <p/>
  * Renders informal parameters, adding CSS class "t-zone" and possibly, "t-invisible".
  */
@@ -43,7 +43,7 @@
 public class Zone implements ClientElement
 {
     /**
-     * Name of a function on the client-side Tapestry.ZoneEffect object that is invoked to
+     * Name of a function on the client-side Tapestry.ElementEffect object that is invoked to
      * make the Zone's &lt;div&gt; visible before being updated.  If not specified, then
      * the basic "show" method is used.
      */
@@ -51,7 +51,7 @@
     private String _show;
 
     /**
-     * Name of a function on the client-side Tapestry.ZoneEffect object that is invoked
+     * Name of a function on the client-side Tapestry.ElementEffect object that is invoked
      * after the Zone's content has been updated. If not specified, then the basic "highlight"
      * method is used, which performs a classic "yellow fade" to indicate to the user
      * that and update has taken place.

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/internal/services/ClientBehaviorSupport.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/internal/services/ClientBehaviorSupport.java?rev=632485&r1=632484&r2=632485&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/internal/services/ClientBehaviorSupport.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry/internal/services/ClientBehaviorSupport.java Fri Feb 29 15:03:56 2008
@@ -29,7 +29,7 @@
     /**
      * Adds a new client-side Tapestry.Zone object. Zones are linked to a an element (typically, a &lt;div&gt;).  A Zone
      * may have handlers used to initially show it, or to highlight it when its content changes. Such handlers are
-     * referenced by name, as functions of the Tapestry.ZoneEffect object.
+     * referenced by name, as functions of the Tapestry.ElementEffect object.
      *
      * @param clientId           client-side id of the element that will be updated by the zone
      * @param showFunctionName   name of the function used to initially show the zone (if not visible), or null for
@@ -51,7 +51,7 @@
      * visible or invisible, which involves interactions with both the server-side and client-side validation.
      *
      * @param clientId         client-side id of the element that will be made visible or invisible
-     * @param showFunctionName name of function (of the Tapestry.ZoneEffect object) used to make the SubForm visible, or
+     * @param showFunctionName name of function (of the Tapestry.ElementEffect object) used to make the SubForm visible, or
      *                         null for the default
      * @param hideFunctionName name of the function used to make the SubForm invisible, or null for the default
      */
@@ -64,7 +64,7 @@
      * @param clientId         client-side id of the element that identifiess where the new content will be placed
      * @param link             action request link used to trigger the server-side object, to render the new content
      * @param insertPosition   where the new content should go (above or below the element)
-     * @param showFunctionName name of function (of the Tapestry.ZoneEffect object) used to make the new element
+     * @param showFunctionName name of function (of the Tapestry.ElementEffect object) used to make the new element
      *                         visible, or null for the default
      */
     void addFormInjector(String clientId, Link link, InsertPosition insertPosition, String showFunctionName);

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry/tapestry.js
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry/tapestry.js?rev=632485&r1=632484&r2=632485&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/site/apt/guide/ajax.apt (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/site/apt/guide/ajax.apt Fri Feb 29 15:03:56 2008
@@ -267,8 +267,8 @@
 ** Zone Functions
 
   A Zone may be initially visible or invisible.  When a Zone is updated, it is made visible if not currently so.
-  This is accomplished via a function on the Tapestry.ZoneEffect client-side object.  By default, the show()
-  function is used for this purpose.  The Zone's show parameter is the <name> of a Tapestry.ZoneEffect function.
+  This is accomplished via a function on the Tapestry.ElementEffect client-side object.  By default, the show()
+  function is used for this purpose.  The Zone's show parameter is the <name> of a Tapestry.ElementEffect function.
 
   If a Zone is already visible, then a different function is used to highlight the change. Here it is
   the Zone's update parameter, and a default highlight() function, which perfroms a yellow fade to highlight
@@ -281,7 +281,7 @@
    then reference those ids inside ActionLink components. Using Zone components inside any kind of loop
    may cause additional problems, as Tapestry will <uniqueify> the client id you specify (appending an index number).
 
-   The show and update function names are converted to lower case; all the methods of Tapestry.ZoneEffect should have
+   The show and update function names are converted to lower case; all the methods of Tapestry.ElementEffect should have
    all lower-case names.  Because client-side JavaScript is so fluid (new methods may be added to
    existing objects), Tapestry makes no attempt to validate the function names ... however, if the names
    are not valid, then the default show and highlight methods will be used.
@@ -295,7 +295,7 @@
 
   * Extending a Form with a Zone
 
-  * Additional Tapestry.ZoneEffect functions, plus documentation
+  * Additional Tapestry.ElementEffect functions, plus documentation
 
   * Real examples ...
 

Modified: tapestry/tapestry5/trunk/tapestry-core/src/site/apt/upgrade.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/site/apt/upgrade.apt?rev=632485&r1=632484&r2=632485&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/site/apt/upgrade.apt (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/site/apt/upgrade.apt Fri Feb 29 15:03:56 2008
@@ -31,6 +31,9 @@
   The show and hide parameters of the {{{ref/org/apache/tapestry/corelib/components/Zone.html}Zone}}
   component now have a default binding prefix of "literal".
 
+  In addition, the client-side Tapestry.ZoneEffect object was renamed to Tapestry.ElementEffect to reflect
+  that it can be used with elements that are not explicitly Zones.
+
 * Validator.invokeIfBlank()
 
   The method <<<invokeIfBlank()>>> on interface {{{../apidocs/org/apache/tapestry/Validator.html}Validator}}
--- tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry/tapestry.js (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/resources/org/apache/tapestry/tapestry.js Fri Feb 29 15:03:56 2008
@@ -669,7 +669,7 @@
 // Wrappers around Prototype and Scriptaculous effects, invoked from Tapestry.Zone.show().
 // All the functions of this object should have all-lowercase names. 
 
-Tapestry.ZoneEffect = {
+Tapestry.ElementEffect = {
 
     show : function(element)
     {
@@ -703,13 +703,13 @@
     // spec are the parameters for the Zone:
     // trigger: required -- name or instance of link.
     // div: required -- name or instance of div element to be shown, hidden and updated
     // show: name of Tapestry.ZoneEffect function used to reveal the zone if hidden
     // update: name of Tapestry.ZoneEffect function used to highlight the zone after it is updated
     initialize: function(spec)
     {
         this.div = $(spec.div);
-        this.showFunc = Tapestry.ZoneEffect[spec.show] || Tapestry.ZoneEffect.show;
-        this.updateFunc = Tapestry.ZoneEffect[spec.update] || Tapestry.ZoneEffect.highlight;
+        this.showFunc = Tapestry.ElementEffect[spec.show] || Tapestry.ElementEffect.show;
+        this.updateFunc = Tapestry.ElementEffect[spec.update] || Tapestry.ElementEffect.highlight;
 
      // Link the div back to this zone.
 
@@ -752,8 +752,8 @@
 
         this.hidden = $(spec.element + ":hidden");
 
-        this.showFunc = Tapestry.ZoneEffect[spec.show] || Tapestry.ZoneEffect.slidedown;
-        this.hideFunc = Tapestry.ZoneEffect[spec.hide] || Tapestry.ZoneEffect.slideup;
+        this.showFunc = Tapestry.ElementEffect[spec.show] || Tapestry.ElementEffect.slidedown;
+        this.hideFunc = Tapestry.ElementEffect[spec.hide] || Tapestry.ElementEffect.slideup;
 
         $(this.hidden.form).observe("form:prepareforsubmit", function()
         {
@@ -797,7 +797,7 @@
         this.url = spec.url;
         this.below = spec.below;
 
-        this.showFunc = Tapestry.ZoneEffect[spec.show] || Tapestry.ZoneEffect.highlight;
+        this.showFunc = Tapestry.ElementEffect[spec.show] || Tapestry.ElementEffect.highlight;
 
         this.element.trigger = function()
         {
@@ -703,13 +703,13 @@
     // trigger: required -- name or instance of link.
     // div: required -- name or instance of div element to be shown, hidden and updated
-    // show: name of Tapestry.ZoneEffect function used to reveal the zone if hidden
-    // update: name of Tapestry.ZoneEffect function used to highlight the zone after it is updated
+    // show: name of Tapestry.ElementEffect function used to reveal the zone if hidden
+    // update: name of Tapestry.ElementEffect function used to highlight the zone after it is updated
     initialize: function(spec)
     {

Modified: tapestry/tapestry5/trunk/tapestry-core/src/site/apt/guide/ajax.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/site/apt/guide/ajax.apt?rev=632485&r1=632484&r2=632485&view=diff
==============================================================================